
1.0b1 (2017-11-15)
------------------

- Support passing query-string parameters to endpoint GET calls.
  [jensens]

- Fix: FileResource.translation endpoint exepects a Accept header with application/octet-stream.
  [jensens]

- Fix: Do not import ``test`` in order to avoid needed  ``responses`` library in non-testing code.
  [jensens]

1.0a1 (2017-11-09)
------------------

- Initial version.
  [jensens]
